@@ -31,6 +31,7 @@ a format object using ``imageio.formats.add_format()``.
 
 import sys
 import warnings
+import contextlib
 
 import numpy as np
 from pathlib import Path
@@ -631,7 +632,15 @@ class FormatManager(object):
 
     @property
     def _formats(self):
-        return [x for x in known_plugins.values() if x.is_legacy]
+        available_formats = list()
+
+        for config in known_plugins.values():
+            with contextlib.suppress(ImportError):
+                # if an exception is raised, then format not installed
+                if config.is_legacy and config.format is not None:
+                    available_formats.append(config)
+
+        return available_formats
 
     def __repr__(self):
         return f"<imageio.FormatManager with {len(self._formats)} registered formats>"
@@ -819,6 +828,14 @@ class FormatManager(object):
         try:
             # in legacy_mode imopen returns a LegacyPlugin
             return imopen(request, request.mode.io_mode, legacy_mode=True)._format
+        except AttributeError:
+            warnings.warn(
+                "ImageIO now uses a v3 plugin when reading this format."
+                " Please migrate to the v3 API (preferred) or use imageio.v2.",
+                DeprecationWarning,
+                stacklevel=2,
+            )
+            return None
         except ValueError:
             # no plugin can read this request
             # but the legacy API doesn't raise
@@ -834,6 +851,14 @@ class FormatManager(object):
         try:
             # in legacy_mode imopen returns a LegacyPlugin
             return imopen(request, request.mode.io_mode, legacy_mode=True)._format
+        except AttributeError:
+            warnings.warn(
+                "ImageIO now uses a v3 plugin when writing this format."
+                " Please migrate to the v3 API (preferred) or use imageio.v2.",
+                DeprecationWarning,
+                stacklevel=2,
+            )
+            return None
         except ValueError:
             # no plugin can write this request
             # but the legacy API doesn't raise
